Message Correction — Poezio 0.9-dev documentation

# Message Correction

Poezio implements the XEP-0308 which allows the correction of the last message sent.

The corrections are signalled with a number append to the nick of the user, in a different color.

The 9 here represents the number of times this message has been corrected.

You can show the revisions of a message by loading the Display corrections plugin, and you can correct your own messages with the /correct command.

Note

Please do not abuse of this feature, as it will simply be displayed as another plain message in the clients that do not support correction.